@@ -47,11 +47,8 @@ class sdk:
     def beskeder(self, id=None):
         return _beskeder.beskeder(self, id=id)
 
-    def lærere(self):
-        return _informationer.lærere(self)
-
-    def elever(self, forbogstav, retry=False):
-        return _informationer.elever(self, forbogstav, retry=retry)
+    def informationer(self):
+        return _informationer.informationer(self)
 
     def fåElev(self, elevId):
         return _informationer.fåElev(self, elevId)
\ No newline at end of file
